@@ -10,11 +10,18 @@ Usage::
     client: ImagebuilderClient = boto3.client("imagebuilder")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_imagebuilder.literals import (
+    ComponentFormat,
+    ComponentType,
+    ContainerType,
+    Ownership,
+    PipelineStatus,
+    Platform,
+)
 from mypy_boto3_imagebuilder.type_defs import (
     CancelImageCreationResponseTypeDef,
     ComponentConfigurationTypeDef,
@@ -74,12 +81,6 @@ from mypy_boto3_imagebuilder.type_defs import (
     UpdateInfrastructureConfigurationResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("ImagebuilderClient",)
 
 
@@ -114,7 +115,7 @@ class Exceptions:
 
 class ImagebuilderClient:
     """
-    [Imagebuilder.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client)
+    [Imagebuilder.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client)
     """
 
     meta: ClientMeta
@@ -122,21 +123,21 @@ class ImagebuilderClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.can_paginate)
         """
 
     def cancel_image_creation(
         self, imageBuildVersionArn: str, clientToken: str
     ) -> CancelImageCreationResponseTypeDef:
         """
-        [Client.cancel_image_creation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.cancel_image_creation)
+        [Client.cancel_image_creation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.cancel_image_creation)
         """
 
     def create_component(
         self,
         name: str,
         semanticVersion: str,
-        platform: Literal["Windows", "Linux"],
+        platform: Platform,
         clientToken: str,
         description: str = None,
         changeDescription: str = None,
@@ -147,12 +148,12 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateComponentResponseTypeDef:
         """
-        [Client.create_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.create_component)
+        [Client.create_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.create_component)
         """
 
     def create_container_recipe(
         self,
-        containerType: Literal["DOCKER"],
+        containerType: ContainerType,
         name: str,
         semanticVersion: str,
         components: List["ComponentConfigurationTypeDef"],
@@ -163,14 +164,14 @@ class ImagebuilderClient:
         instanceConfiguration: "InstanceConfigurationTypeDef" = None,
         dockerfileTemplateData: str = None,
         dockerfileTemplateUri: str = None,
-        platformOverride: Literal["Windows", "Linux"] = None,
+        platformOverride: Platform = None,
         imageOsVersionOverride: str = None,
         tags: Dict[str, str] = None,
         workingDirectory: str = None,
         kmsKeyId: str = None,
     ) -> CreateContainerRecipeResponseTypeDef:
         """
-        [Client.create_container_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.create_container_recipe)
+        [Client.create_container_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.create_container_recipe)
         """
 
     def create_distribution_configuration(
@@ -182,7 +183,7 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateDistributionConfigurationResponseTypeDef:
         """
-        [Client.create_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.create_distribution_configuration)
+        [Client.create_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.create_distribution_configuration)
         """
 
     def create_image(
@@ -197,7 +198,7 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateImageResponseTypeDef:
         """
-        [Client.create_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.create_image)
+        [Client.create_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.create_image)
         """
 
     def create_image_pipeline(
@@ -212,11 +213,11 @@ class ImagebuilderClient:
         imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = None,
         enhancedImageMetadataEnabled: bool = None,
         schedule: "ScheduleTypeDef" = None,
-        status: Literal["DISABLED", "ENABLED"] = None,
+        status: PipelineStatus = None,
         tags: Dict[str, str] = None,
     ) -> CreateImagePipelineResponseTypeDef:
         """
-        [Client.create_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_pipeline)
+        [Client.create_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_pipeline)
         """
 
     def create_image_recipe(
@@ -232,7 +233,7 @@ class ImagebuilderClient:
         workingDirectory: str = None,
     ) -> CreateImageRecipeResponseTypeDef:
         """
-        [Client.create_image_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_recipe)
+        [Client.create_image_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.create_image_recipe)
         """
 
     def create_infrastructure_configuration(
@@ -252,48 +253,48 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> CreateInfrastructureConfigurationResponseTypeDef:
         """
-        [Client.create_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.create_infrastructure_configuration)
+        [Client.create_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.create_infrastructure_configuration)
         """
 
     def delete_component(self, componentBuildVersionArn: str) -> DeleteComponentResponseTypeDef:
         """
-        [Client.delete_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.delete_component)
+        [Client.delete_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.delete_component)
         """
 
     def delete_container_recipe(
         self, containerRecipeArn: str
     ) -> DeleteContainerRecipeResponseTypeDef:
         """
-        [Client.delete_container_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.delete_container_recipe)
+        [Client.delete_container_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.delete_container_recipe)
         """
 
     def delete_distribution_configuration(
         self, distributionConfigurationArn: str
     ) -> DeleteDistributionConfigurationResponseTypeDef:
         """
-        [Client.delete_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.delete_distribution_configuration)
+        [Client.delete_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.delete_distribution_configuration)
         """
 
     def delete_image(self, imageBuildVersionArn: str) -> DeleteImageResponseTypeDef:
         """
-        [Client.delete_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image)
+        [Client.delete_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image)
         """
 
     def delete_image_pipeline(self, imagePipelineArn: str) -> DeleteImagePipelineResponseTypeDef:
         """
-        [Client.delete_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_pipeline)
+        [Client.delete_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_pipeline)
         """
 
     def delete_image_recipe(self, imageRecipeArn: str) -> DeleteImageRecipeResponseTypeDef:
         """
-        [Client.delete_image_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_recipe)
+        [Client.delete_image_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.delete_image_recipe)
         """
 
     def delete_infrastructure_configuration(
         self, infrastructureConfigurationArn: str
     ) -> DeleteInfrastructureConfigurationResponseTypeDef:
         """
-        [Client.delete_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.delete_infrastructure_configuration)
+        [Client.delete_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.delete_infrastructure_configuration)
         """
 
     def generate_presigned_url(
@@ -304,77 +305,77 @@ class ImagebuilderClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.generate_presigned_url)
         """
 
     def get_component(self, componentBuildVersionArn: str) -> GetComponentResponseTypeDef:
         """
-        [Client.get_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_component)
+        [Client.get_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_component)
         """
 
     def get_component_policy(self, componentArn: str) -> GetComponentPolicyResponseTypeDef:
         """
-        [Client.get_component_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_component_policy)
+        [Client.get_component_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_component_policy)
         """
 
     def get_container_recipe(self, containerRecipeArn: str) -> GetContainerRecipeResponseTypeDef:
         """
-        [Client.get_container_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe)
+        [Client.get_container_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe)
         """
 
     def get_container_recipe_policy(
         self, containerRecipeArn: str
     ) -> GetContainerRecipePolicyResponseTypeDef:
         """
-        [Client.get_container_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe_policy)
+        [Client.get_container_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_container_recipe_policy)
         """
 
     def get_distribution_configuration(
         self, distributionConfigurationArn: str
     ) -> GetDistributionConfigurationResponseTypeDef:
         """
-        [Client.get_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_distribution_configuration)
+        [Client.get_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_distribution_configuration)
         """
 
     def get_image(self, imageBuildVersionArn: str) -> GetImageResponseTypeDef:
         """
-        [Client.get_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_image)
+        [Client.get_image documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_image)
         """
 
     def get_image_pipeline(self, imagePipelineArn: str) -> GetImagePipelineResponseTypeDef:
         """
-        [Client.get_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_pipeline)
+        [Client.get_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_pipeline)
         """
 
     def get_image_policy(self, imageArn: str) -> GetImagePolicyResponseTypeDef:
         """
-        [Client.get_image_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_policy)
+        [Client.get_image_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_policy)
         """
 
     def get_image_recipe(self, imageRecipeArn: str) -> GetImageRecipeResponseTypeDef:
         """
-        [Client.get_image_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe)
+        [Client.get_image_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe)
         """
 
     def get_image_recipe_policy(self, imageRecipeArn: str) -> GetImageRecipePolicyResponseTypeDef:
         """
-        [Client.get_image_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe_policy)
+        [Client.get_image_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_image_recipe_policy)
         """
 
     def get_infrastructure_configuration(
         self, infrastructureConfigurationArn: str
     ) -> GetInfrastructureConfigurationResponseTypeDef:
         """
-        [Client.get_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.get_infrastructure_configuration)
+        [Client.get_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.get_infrastructure_configuration)
         """
 
     def import_component(
         self,
         name: str,
         semanticVersion: str,
-        type: Literal["BUILD", "TEST"],
-        format: Literal["SHELL"],
-        platform: Literal["Windows", "Linux"],
+        type: ComponentType,
+        format: ComponentFormat,
+        platform: Platform,
         clientToken: str,
         description: str = None,
         changeDescription: str = None,
@@ -384,44 +385,44 @@ class ImagebuilderClient:
         tags: Dict[str, str] = None,
     ) -> ImportComponentResponseTypeDef:
         """
-        [Client.import_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.import_component)
+        [Client.import_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.import_component)
         """
 
     def list_component_build_versions(
         self, componentVersionArn: str, maxResults: int = None, nextToken: str = None
     ) -> ListComponentBuildVersionsResponseTypeDef:
         """
-        [Client.list_component_build_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_component_build_versions)
+        [Client.list_component_build_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_component_build_versions)
         """
 
     def list_components(
         self,
-        owner: Literal["Self", "Shared", "Amazon"] = None,
+        owner: Ownership = None,
         filters: List[FilterTypeDef] = None,
         byName: bool = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListComponentsResponseTypeDef:
         """
-        [Client.list_components documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_components)
+        [Client.list_components documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_components)
         """
 
     def list_container_recipes(
         self,
-        owner: Literal["Self", "Shared", "Amazon"] = None,
+        owner: Ownership = None,
         filters: List[FilterTypeDef] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListContainerRecipesResponseTypeDef:
         """
-        [Client.list_container_recipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_container_recipes)
+        [Client.list_container_recipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_container_recipes)
         """
 
     def list_distribution_configurations(
         self, filters: List[FilterTypeDef] = None, maxResults: int = None, nextToken: str = None
     ) -> ListDistributionConfigurationsResponseTypeDef:
         """
-        [Client.list_distribution_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_distribution_configurations)
+        [Client.list_distribution_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_distribution_configurations)
         """
 
     def list_image_build_versions(
@@ -432,14 +433,14 @@ class ImagebuilderClient:
         nextToken: str = None,
     ) -> ListImageBuildVersionsResponseTypeDef:
         """
-        [Client.list_image_build_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_build_versions)
+        [Client.list_image_build_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_build_versions)
         """
 
     def list_image_packages(
         self, imageBuildVersionArn: str, maxResults: int = None, nextToken: str = None
     ) -> ListImagePackagesResponseTypeDef:
         """
-        [Client.list_image_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_packages)
+        [Client.list_image_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_packages)
         """
 
     def list_image_pipeline_images(
@@ -450,30 +451,30 @@ class ImagebuilderClient:
         nextToken: str = None,
     ) -> ListImagePipelineImagesResponseTypeDef:
         """
-        [Client.list_image_pipeline_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipeline_images)
+        [Client.list_image_pipeline_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipeline_images)
         """
 
     def list_image_pipelines(
         self, filters: List[FilterTypeDef] = None, maxResults: int = None, nextToken: str = None
     ) -> ListImagePipelinesResponseTypeDef:
         """
-        [Client.list_image_pipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipelines)
+        [Client.list_image_pipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_pipelines)
         """
 
     def list_image_recipes(
         self,
-        owner: Literal["Self", "Shared", "Amazon"] = None,
+        owner: Ownership = None,
         filters: List[FilterTypeDef] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListImageRecipesResponseTypeDef:
         """
-        [Client.list_image_recipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_recipes)
+        [Client.list_image_recipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_image_recipes)
         """
 
     def list_images(
         self,
-        owner: Literal["Self", "Shared", "Amazon"] = None,
+        owner: Ownership = None,
         filters: List[FilterTypeDef] = None,
         byName: bool = None,
         maxResults: int = None,
@@ -481,62 +482,62 @@ class ImagebuilderClient:
         includeDeprecated: bool = None,
     ) -> ListImagesResponseTypeDef:
         """
-        [Client.list_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_images)
+        [Client.list_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_images)
         """
 
     def list_infrastructure_configurations(
         self, filters: List[FilterTypeDef] = None, maxResults: int = None, nextToken: str = None
     ) -> ListInfrastructureConfigurationsResponseTypeDef:
         """
-        [Client.list_infrastructure_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_infrastructure_configurations)
+        [Client.list_infrastructure_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_infrastructure_configurations)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.list_tags_for_resource)
         """
 
     def put_component_policy(
         self, componentArn: str, policy: str
     ) -> PutComponentPolicyResponseTypeDef:
         """
-        [Client.put_component_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.put_component_policy)
+        [Client.put_component_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.put_component_policy)
         """
 
     def put_container_recipe_policy(
         self, containerRecipeArn: str, policy: str
     ) -> PutContainerRecipePolicyResponseTypeDef:
         """
-        [Client.put_container_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.put_container_recipe_policy)
+        [Client.put_container_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.put_container_recipe_policy)
         """
 
     def put_image_policy(self, imageArn: str, policy: str) -> PutImagePolicyResponseTypeDef:
         """
-        [Client.put_image_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_policy)
+        [Client.put_image_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_policy)
         """
 
     def put_image_recipe_policy(
         self, imageRecipeArn: str, policy: str
     ) -> PutImageRecipePolicyResponseTypeDef:
         """
-        [Client.put_image_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_recipe_policy)
+        [Client.put_image_recipe_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.put_image_recipe_policy)
         """
 
     def start_image_pipeline_execution(
         self, imagePipelineArn: str, clientToken: str
     ) -> StartImagePipelineExecutionResponseTypeDef:
         """
-        [Client.start_image_pipeline_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.start_image_pipeline_execution)
+        [Client.start_image_pipeline_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.start_image_pipeline_execution)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.untag_resource)
         """
 
     def update_distribution_configuration(
@@ -547,7 +548,7 @@ class ImagebuilderClient:
         description: str = None,
     ) -> UpdateDistributionConfigurationResponseTypeDef:
         """
-        [Client.update_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.update_distribution_configuration)
+        [Client.update_distribution_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.update_distribution_configuration)
         """
 
     def update_image_pipeline(
@@ -562,10 +563,10 @@ class ImagebuilderClient:
         imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = None,
         enhancedImageMetadataEnabled: bool = None,
         schedule: "ScheduleTypeDef" = None,
-        status: Literal["DISABLED", "ENABLED"] = None,
+        status: PipelineStatus = None,
     ) -> UpdateImagePipelineResponseTypeDef:
         """
-        [Client.update_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.update_image_pipeline)
+        [Client.update_image_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.update_image_pipeline)
         """
 
     def update_infrastructure_configuration(
@@ -584,5 +585,5 @@ class ImagebuilderClient:
         resourceTags: Dict[str, str] = None,
     ) -> UpdateInfrastructureConfigurationResponseTypeDef:
         """
-        [Client.update_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/imagebuilder.html#Imagebuilder.Client.update_infrastructure_configuration)
+        [Client.update_infrastructure_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/imagebuilder.html#Imagebuilder.Client.update_infrastructure_configuration)
         """
